package com.fs.survey.service;

import java.util.List;
import com.fs.survey.domain.SurveyTask;

/**
 * 问卷任务主Service接口
 * 
 * @author fs
 * @date 2026-02-06
 */
public interface ISurveyTaskService 
{
    /**
     * 查询问卷任务主
     * 
     * @param id 问卷任务主主键
     * @return 问卷任务主
     */
    public SurveyTask selectSurveyTaskById(Long id);

    /**
     * 查询问卷任务主列表
     * 
     * @param surveyTask 问卷任务主
     * @return 问卷任务主集合
     */
    public List<SurveyTask> selectSurveyTaskList(SurveyTask surveyTask);

    /**
     * 新增问卷任务主
     * 
     * @param surveyTask 问卷任务主
     * @return 结果
     */
    public int insertSurveyTask(SurveyTask surveyTask);

    /**
     * 修改问卷任务主
     * 
     * @param surveyTask 问卷任务主
     * @return 结果
     */
    public int updateSurveyTask(SurveyTask surveyTask);

    /**
     * 批量删除问卷任务主
     * 
     * @param ids 需要删除的问卷任务主主键集合
     * @return 结果
     */
    public int deleteSurveyTaskByIds(Long[] ids);

    /**
     * 删除问卷任务主信息
     * 
     * @param id 问卷任务主主键
     * @return 结果
     */
    public int deleteSurveyTaskById(Long id);

    int updateSurveyTaskBaseInfo(SurveyTask surveyTask);
}
